==> dl.php?src=linea21_1_3_1.zip: linea21/languages/es/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
*  	*/
$lang['theme']['name']="área";
$lang['theme']['confirm_add'] = "Área añadida correctamente";
$lang['theme']['confirm_mod'] = "Área actualizada correctamente";
$lang['theme']['confirm_sup'] ="Área eliminada correctamente";

/*	nommage rubrique add / mod /det
*  	*/
$lang['theme']['add_title']="Añadir valores al nuevo ".$lang['theme']['name'];
$lang['theme']['mod_title']="Editar los valores del ".$lang['theme']['name'];


/*	nommage rubrique module
*  	*/
$lang['theme']['add']= "Añadir nueva ".$lang['theme']['name'];
$lang['theme']['mod']= "Editar ".$lang['theme']['name'];
$lang['theme']['sup']= "Eliminar ".$lang['theme']['name'];
$lang['theme']['det']= ucfirst($lang['theme']['name']) . " detalles";
$lang['theme']['list']= "Ver áreas";
$lang['sdtheme']['det']= "desarrollo sostenible área detalles";

/*	nommage élément rubrique
*  	*/
$lang['theme']['is_root']="Principal área";
$lang['theme']['denomination']="Denominación";
$lang['theme']['sdtheme']="Área de desarrollo sostenible";
$lang['theme']['photouri']="Imagen asociada";
$lang['theme']['statut']="Estado";

$lang['theme']['description']="Descripción";
$lang['theme']['description_all']="Descripción general (para todos los módulos)";
$lang['theme']['desc_all']="Descripción general.";
$lang['theme']['description_det']="Descripción por módulo.";
$lang['theme']['desc_det_project']="Proyectos  (descripción)";
$lang['theme']['desc_det_dashboard']="Panel de indicadores (descripción)";
$lang['theme']['desc_det_publication']="Publicaciones (descripción)";
$lang['theme']['desc_det_news']="Noticias (descripción)";
$lang['theme']['desc_det_workshop']="Grupos de trabajo (descripción)";
$lang['theme']['desc_det_forum']="Foros (descripción)";

/*	nommage rubrique sup
*  	*/
$lang['theme']['sup_massd']= "Eliminar recursos asociados";
$lang['theme']['sup_massm']= "Adjuntar todos los recursos asociados a otro área"; 
$lang['theme']['sup_transfert']= "Área transferida"; 

/*	nommage quickbox
*  	*/
$lang['theme']['qb_titleadd']=" áreas agregadas recientemente";
$lang['theme']['qb_titlemod']=" áreas modificadas recientemente";
$lang['theme']['qb_titlesup']=" áreas eliminadas recientemente";

/*	messages
*  	*/
$lang['theme']['object_notdenomination']="La denominación es requerida";
$lang['theme']['object_notSDtheme']="La asociación con el área es requerida";
$lang['theme']['object_notdesc_completed']="La descripción para cada módulo es requerida";
$lang['theme']['object_notstatus']="El estado es requerido";
$lang['theme']['sup_nomethod']="¡Los metodos de eliminación son requeridos!";
$lang['theme']['sup_notheme']="¡El área transferida es requerida!";
$lang['theme']['sup_mass_delete']="¡Atención, la eliminación del área también eliminará los recursos asociados!";
$lang['theme']['sup_mass_modify']="¡Atención, la transferencia del área también transferirá los recursos asociados!";

/*	rubrique d'aide
*  	*/
$lang['theme']['help_add1']="Para añadir un área temática, inserte la información requerida en el formulario.";
$lang['theme']['help_add2']="Los campos con asterisco son obligatorios.";
$lang['theme']['help_add3']="Completado el formulario, revise los valores en el resumen.";
$lang['theme']['help_add4']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['theme']['help_list1']="Para más información haga click en el título del área temática.";
$lang['theme']['help_list2']="Para eliminar un área temática, haga click en el icono 'eliminar área'.";
$lang['theme']['help_list3']="Para editar un área temática, haga click en el icono 'editar área'.";
$lang['theme']['help_list4']="Para añadir una nueva área temática, haga click en 'añadir nueva área'.";
$lang['theme']['help_list5']="Si desea realizar búsquedas dentro del módulo 'áreas temáticas', haga click en 'buscar'.";


$lang['theme']['help_mod1']="Para editar un área temática, inserte la información requerida en el formulario.";
$lang['theme']['help_mod2']="Completado el formulario, revise los valores en el resumen.";
$lang['theme']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['theme']['help_det1']="Para ver la escala superior, haga click en el título del área temática";
$lang['theme']['help_det2']="Para eliminar un área temática, haga click en el icono 'eliminar área'";
$lang['theme']['help_det3']="Para editar un área temática, haga click en el icono 'editar área'";
$lang['sdtheme']['help_det1']="Este área es un eje fundamental de desarrollo sostenible. No puede editarse ni eliminarse.";


$lang['theme']['help_sup1']="El método de eliminación es requerido";
$lang['theme']['help_sup2']="El código de seguridad es requerido";
$lang['theme']['help_sup3']="Atención, la eliminación de un área temática conlleva cambios en toda la aplicación; se recomienda que esta eliminación sea utilizada únicamente por expertos.";

?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/es/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
 *  	*/
$lang['theme']['name']="área";
$lang['theme']['confirm_add'] = "Área añadida correctamente";
$lang['theme']['confirm_mod'] = "Área actualizada correctamente";
$lang['theme']['confirm_sup'] ="Área eliminada correctamente";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['theme']['add_title']="Añadir valores al nuevo ".$lang['theme']['name'];
$lang['theme']['mod_title']="Editar los valores del ".$lang['theme']['name'];


/*	nommage rubrique module
 *  	*/
$lang['theme']['add']= "Añadir nueva ".$lang['theme']['name'];
$lang['theme']['mod']= "Editar ".$lang['theme']['name'];
$lang['theme']['sup']= "Eliminar ".$lang['theme']['name'];
$lang['theme']['det']= ucfirst($lang['theme']['name']) . " detalles";
$lang['theme']['list']= "Ver áreas";
$lang['sdtheme']['det']= "principal área detalles";

/*	nommage élément rubrique
 *  	*/
$lang['theme']['is_root']="Principal área ?";
$lang['theme']['denomination']="Denominación";
$lang['theme']['sdtheme']="Principal área";
$lang['theme']['photouri']="Imagen asociada";
$lang['theme']['statut']="Estado";

$lang['theme']['description']="Descripción";
$lang['theme']['description_all']="Descripción general (para todos los módulos)";
$lang['theme']['desc_all']="Descripción general.";
$lang['theme']['description_det']="Descripción por módulo.";
$lang['theme']['desc_det_project']="Proyectos  (descripción)";
$lang['theme']['desc_det_dashboard']="Panel de indicadores (descripción)";
$lang['theme']['desc_det_publication']="Publicaciones (descripción)";
$lang['theme']['desc_det_news']="Noticias (descripción)";
$lang['theme']['desc_det_workshop']="Grupos de trabajo (descripción)";
$lang['theme']['desc_det_forum']="Foros (descripción)";

/*	nommage rubrique sup
 *  	*/
$lang['theme']['sup_massd']= "Eliminar recursos asociados";
$lang['theme']['sup_massm']= "Adjuntar todos los recursos asociados a otro área";
$lang['theme']['sup_transfert']= "Área transferida";

/*	nommage quickbox
 *  	*/
$lang['theme']['qb_titleadd']=" áreas agregadas recientemente";
$lang['theme']['qb_titlemod']=" áreas modificadas recientemente";
$lang['theme']['qb_titlesup']=" áreas eliminadas recientemente";

/*	messages
 *  	*/
$lang['theme']['object_notdenomination']="La denominación es requerida";
$lang['theme']['object_notSDtheme']="La asociación con el área es requerida";
$lang['theme']['object_notdesc_completed']="La descripción para cada módulo es requerida";
$lang['theme']['object_notstatus']="El estado es requerido";
$lang['theme']['sup_nomethod']="¡Los metodos de eliminación son requeridos!";
$lang['theme']['sup_notheme']="¡El área transferida es requerida!";
$lang['theme']['sup_mass_delete']="¡Atención, la eliminación del área también eliminará los recursos asociados!";
$lang['theme']['sup_mass_modify']="¡Atención, la transferencia del área también transferirá los recursos asociados!";

/*	rubrique d'aide
 *  	*/
$lang['theme']['help_add1']="Para añadir un área temática, inserte la información requerida en el formulario.";
$lang['theme']['help_add2']="Los campos con asterisco son obligatorios.";
$lang['theme']['help_add3']="Completado el formulario, revise los valores en el resumen.";
$lang['theme']['help_add4']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['theme']['help_list1']="Para más información haga click en el título del área temática.";
$lang['theme']['help_list2']="Para eliminar un área temática, haga click en el icono 'eliminar área'.";
$lang['theme']['help_list3']="Para editar un área temática, haga click en el icono 'editar área'.";
$lang['theme']['help_list4']="Para añadir una nueva área temática, haga click en 'añadir nueva área'.";
$lang['theme']['help_list5']="Si desea realizar búsquedas dentro del módulo 'áreas temáticas', haga click en 'buscar'.";


$lang['theme']['help_mod1']="Para editar un área temática, inserte la información requerida en el formulario.";
$lang['theme']['help_mod2']="Completado el formulario, revise los valores en el resumen.";
$lang['theme']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['theme']['help_det1']="Para ver la escala superior, haga click en el título del área temática";
$lang['theme']['help_det2']="Para eliminar un área temática, haga click en el icono 'eliminar área'";
$lang['theme']['help_det3']="Para editar un área temática, haga click en el icono 'editar área'";
$lang['sdtheme']['help_det1']="Este área es un eje fundamental de desarrollo sostenible. No puede editarse ni eliminarse.";


$lang['theme']['help_sup1']="El método de eliminación es requerido";
$lang['theme']['help_sup2']="El código de seguridad es requerido";
$lang['theme']['help_sup3']="Atención, la eliminación de un área temática conlleva cambios en toda la aplicación; se recomienda que esta eliminación sea utilizada únicamente por expertos.";

?>
